@@ -1,23 +1,20 @@
 from __future__ import annotations
 
-import multiprocessing
 import os
 from pathlib import Path
-from typing import Union
+from typing import Optional
 
 from rich.console import Console
 
 from pls.args import args
 from pls.enums.node_type import NodeType
-from pls.enums.sort_order import SortOrder
 from pls.models.node import Node
-from pls.state import State, state
 
 
 console = Console()
 
 
-def sort_key(node: Node) -> str:
+def sort_key(node: Node) -> tuple:
     """
     Map a ``Node`` instance to a string that represents it. This string is used
     to sort a list of ``Node`` instances.
@@ -26,23 +23,23 @@ def sort_key(node: Node) -> str:
     :return: a string representative of the node
     """
 
-    key = node.name.lstrip(".").lower()
+    key = node.sort_keys[args.sort.rstrip("-")]
+    is_reversed = args.sort.endswith("-")
     if not args.no_dirs_first:
-        prefix = "0" if node.node_type == NodeType.DIR else "1"
-        key = f"{prefix}{key}"
-    return key
+        if is_reversed:
+            type_key = 1 if node.node_type == NodeType.DIR else 0
+        else:
+            type_key = 0 if node.node_type == NodeType.DIR else 1
+        return type_key, key, node.sort_keys["name"]
+    return key, node.name
 
 
-def parse_nodes(node_name: str, parent_state: State) -> Union[Node, None]:
+def parse_node(node_name: str) -> Optional[Node]:
     """
     Parse the node name into a ``Node`` instance. Most of the heavy lifting is
     handled in the ``Node`` class definition itself.
 
-    This function is executed by multiprocessing workers and thus must be
-    passed the state explicitly from the main process.
-
     :param node_name: the name of a node inside the working directory
-    :param parent_state: the global state of the parent application
     :return: a ``Node`` instance
     """
 
@@ -55,10 +52,10 @@ def parse_nodes(node_name: str, parent_state: State) -> Union[Node, None]:
         if args.no_files:
             return None
 
-    return Node(node_name, path=node_path, state=parent_state)
+    return Node(node_name, path=node_path)
 
 
-def read_input() -> list[Node]:
+def read_input() -> tuple[dict[str, Node], list[Node]]:
     """
     Get a list of all directories and files in the given directory.
 
@@ -67,18 +64,21 @@ def read_input() -> list[Node]:
 
     all_nodes = os.listdir(args.directory)
 
+    node_map = {}
+    node_list = []
+
     if not all_nodes:
         console.print(
             f"There are no files or folders in [bold]{args.directory}[/bold].",
             highlight=False,
         )
     else:
-        with multiprocessing.Pool() as pool:
-            comp_nodes = pool.starmap(
-                parse_nodes,
-                [(node, state) for node in all_nodes],
-            )
-        all_nodes = [node for node in comp_nodes if node is not None]
-        all_nodes.sort(key=sort_key, reverse=args.sort == SortOrder.DESC)
+        node_map = {
+            parsed_node.name: parsed_node
+            for node in all_nodes
+            if (parsed_node := parse_node(node)) is not None
+        }
+        node_list = list(node_map.values())
+        node_list.sort(key=sort_key, reverse=args.sort.endswith("-"))
 
-    return all_nodes
+    return node_map, node_list
